==> blesta-5.10.2.zip: blesta/language/sv_se/admin_company_clientoptions.php <==
<?php
/**
 * Admin Company Clientoptions
 *
 * @package blesta
 * @subpackage blesta.language.sv_se
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminCompanyClientOptions.requiredfields.text_submit'] = 'Uppdatera inställningar';
$lang['AdminCompanyClientOptions.requiredfields.field_fax'] = 'Fax';
$lang['AdminCompanyClientOptions.requiredfields.field_phone'] = 'Telefon';
$lang['AdminCompanyClientOptions.requiredfields.field_email'] = 'E-post';
$lang['AdminCompanyClientOptions.requiredfields.field_zip'] = 'Postnummer';
$lang['AdminCompanyClientOptions.requiredfields.field_state'] = 'Stat/Provins';
$lang['AdminCompanyClientOptions.requiredfields.field_country'] = 'Land';
$lang['AdminCompanyClientOptions.requiredfields.field_city'] = 'Stad';
$lang['AdminCompanyClientOptions.requiredfields.field_address2'] = 'Adress 2';
$lang['AdminCompanyClientOptions.requiredfields.field_address1'] = 'Adress 1';
$lang['AdminCompanyClientOptions.requiredfields.field_title'] = 'Titel';
$lang['AdminCompanyClientOptions.requiredfields.field_company'] = 'Företag/Org.';
$lang['AdminCompanyClientOptions.requiredfields.field_last_name'] = 'Efternamn';
$lang['AdminCompanyClientOptions.requiredfields.field_first_name'] = 'Förnamn';
$lang['AdminCompanyClientOptions.requiredfields.heading_read_only'] = 'Endast läsning';
$lang['AdminCompanyClientOptions.requiredfields.heading_show'] = 'Visa';
$lang['AdminCompanyClientOptions.requiredfields.heading_required'] = 'Obligatoriskt';
$lang['AdminCompanyClientOptions.requiredfields.heading_field'] = 'Fält';
$lang['AdminCompanyClientOptions.requiredfields.description'] = 'Markera de fält som ska vara obligatoriska när du skapar eller uppdaterar en klient eller kontakt.';
$lang['AdminCompanyClientOptions.requiredfields.boxtitle'] = 'Obligatoriska fält för kunden';
$lang['AdminCompanyClientoptions.requiredfields.page_title'] = 'Inställningar > Företag > Kundalternativ > Kundanpassade fält > Obligatoriska kundfält';
$lang['AdminCompanyClientOptions.getRequired.regex'] = 'Anpassad Regex';
$lang['AdminCompanyClientOptions.getRequired.yes'] = 'Ja';
$lang['AdminCompanyClientOptions.getRequired.no'] = 'Nej';
$lang['AdminCompanyClientOptions.editcustomfield.text_remove'] = 'Ta bort';
$lang['AdminCompanyClientOptions.editcustomfield.heading_select_default'] = 'Standard';
$lang['AdminCompanyClientOptions.editcustomfield.heading_select_option'] = 'Alternativets namn';
$lang['AdminCompanyClientOptions.editcustomfield.heading_select_value'] = 'Värde';
$lang['AdminCompanyClientOptions.editcustomfield.categorylink_select'] = 'Lägg till ytterligare alternativ';
$lang['AdminCompanyClientOptions.editcustomfield.field.default_text'] = 'Standardvärde för text';
$lang['AdminCompanyClientOptions.editcustomfield.field.default_checkbox'] = 'Standardvärde Kontrollerat';
$lang['AdminCompanyClientOptions.editcustomfield.field.checkbox_value'] = 'Värde';
$lang['AdminCompanyClientOptions.editcustomfield.field.editsubmit'] = 'Redigera anpassat fält';
$lang['AdminCompanyClientOptions.editcustomfield.field.encrypted'] = 'Kryptera värden';
$lang['AdminCompanyClientOptions.editcustomfield.field.regex'] = 'Anpassad Regex';
$lang['AdminCompanyClientOptions.editcustomfield.field.required'] = 'Obligatoriskt';
$lang['AdminCompanyClientOptions.editcustomfield.field.read_only'] = 'Endast läsning för klienter';
$lang['AdminCompanyClientOptions.editcustomfield.field.show_client'] = 'Synlig för kunder';
$lang['AdminCompanyClientOptions.editcustomfield.field.type'] = 'Typ';
$lang['AdminCompanyClientOptions.editcustomfield.field.link'] = 'Länk';
$lang['AdminCompanyClientOptions.editcustomfield.field.is_lang'] = 'Namn är en språkdefinition';
$lang['AdminCompanyClientOptions.editcustomfield.field.name'] = 'Namn';
$lang['AdminCompanyClientOptions.editcustomfield.boxtitle_edit'] = 'Redigera anpassat fält';
$lang['AdminCompanyClientoptions.editcustomfield.page_title'] = 'Inställningar > Företag > Klientalternativ > Klientanpassade fält > Redigera anpassat fält';
$lang['AdminCompanyClientOptions.addcustomfield.text_remove'] = 'Ta bort';
$lang['AdminCompanyClientOptions.addcustomfield.heading_select_default'] = 'Standard';
$lang['AdminCompanyClientOptions.addcustomfield.heading_select_option'] = 'Alternativets namn';
$lang['AdminCompanyClientOptions.addcustomfield.heading_select_value'] = 'Värde';
$lang['AdminCompanyClientOptions.addcustomfield.categorylink_select'] = 'Lägg till ytterligare alternativ';
$lang['AdminCompanyClientOptions.addcustomfield.configuration_warning'] = 'Att kräva detta fält men inte göra det synligt för kunderna kommer att leda till att kunderna inte kan registrera eller uppdatera sin kontoinformation.';
$lang['AdminCompanyClientOptions.addcustomfield.field.default_text'] = 'Standardvärde för text';
$lang['AdminCompanyClientOptions.addcustomfield.field.default_checkbox'] = 'Standardvärde Kontrollerat';
$lang['AdminCompanyClientOptions.addcustomfield.field.checkbox_value'] = 'Värde';
$lang['AdminCompanyClientOptions.addcustomfield.field.addsubmit'] = 'Lägg till anpassat fält';
$lang['AdminCompanyClientOptions.addcustomfield.field.encrypted'] = 'Kryptera värden';
$lang['AdminCompanyClientOptions.addcustomfield.field.regex'] = 'Anpassad Regex';
$lang['AdminCompanyClientOptions.addcustomfield.field.required'] = 'Obligatoriskt';
$lang['AdminCompanyClientOptions.addcustomfield.field.read_only'] = 'Endast läsning för klienter';
$lang['AdminCompanyClientOptions.addcustomfield.field.show_client'] = 'Synlig för kunder';
$lang['AdminCompanyClientOptions.addcustomfield.field.type'] = 'Typ';
$lang['AdminCompanyClientOptions.addcustomfield.field.link'] = 'Länk';
$lang['AdminCompanyClientOptions.addcustomfield.field.is_lang'] = 'Namn är en språkdefinition';
$lang['AdminCompanyClientOptions.addcustomfield.field.name'] = 'Namn';
$lang['AdminCompanyClientOptions.addcustomfield.field.client_group_id'] = 'Kundgrupp';
$lang['AdminCompanyClientOptions.addcustomfield.boxtitle_add'] = 'Lägg till anpassat fält';
$lang['AdminCompanyClientoptions.addcustomfield.page_title'] = 'Inställningar > Företag > Klientalternativ > Klientanpassade fält > Lägg till anpassat fält';
$lang['AdminCompanyClientOptions.customfields.no_results'] = 'Det finns inga anpassade fält.';
$lang['AdminCompanyClientOptions.customfields.confirm_delete'] = 'Om du tar bort detta anpassade fält raderas alla data som lagrats för det för varje klient inom denna grupp. Är du säker på att du vill ta bort det här anpassade fältet?';
$lang['AdminCompanyClientOptions.customfields.option_delete'] = 'Radera';
$lang['AdminCompanyClientOptions.customfields.option_edit'] = 'Redigera';
$lang['AdminCompanyClientOptions.customfields.text_options'] = 'Alternativ';
$lang['AdminCompanyClientOptions.customfields.text_read_only'] = 'Endast läsning för klienter';
$lang['AdminCompanyClientOptions.customfields.text_visible'] = 'Synlig för kunder';
$lang['AdminCompanyClientOptions.customfields.text_required'] = 'Obligatoriskt';
$lang['AdminCompanyClientOptions.customfields.text_type'] = 'Typ';
$lang['AdminCompanyClientOptions.customfields.text_name'] = 'Namn';
$lang['AdminCompanyClientOptions.customfields.categorylink_addfield'] = 'Skapa fält';
$lang['AdminCompanyClientOptions.customfields.boxtitle_browse'] = 'Bläddra bland anpassade fält för klienter';
$lang['AdminCompanyClientoptions.customfields.page_title'] = 'Inställningar > Företag > Kundalternativ > Kundanpassade fält > Bläddra';
$lang['AdminCompanyClientOptions.general.text_submit'] = 'Skicka in';
$lang['AdminCompanyClientOptions.general.prevent_unverified_payments'] = 'Förhindra betalningar från icke-verifierade kunder';
$lang['AdminCompanyClientOptions.general.field_clients_increment'] = 'Klient-ID Inkrementvärde';
$lang['AdminCompanyClientOptions.general.field_clients_start'] = 'Kund-ID Startvärde';
$lang['AdminCompanyClientOptions.general.field_clients_format'] = 'Format för klient-ID';
$lang['AdminCompanyClientOptions.general.field_email_verification'] = 'Aktivera e-postverifiering';
$lang['AdminCompanyClientOptions.general.field_force_email_usernames'] = 'Tvinga fram användarnamn för e-post';
$lang['AdminCompanyClientOptions.general.field_unique_contact_emails_all'] = 'Alla kontakter';
$lang['AdminCompanyClientOptions.general.field_unique_contact_emails_primary'] = 'Primära kontakter';
$lang['AdminCompanyClientOptions.general.field_unique_contact_emails_none'] = '-- Inga';
$lang['AdminCompanyClientOptions.general.field_unique_contact_emails'] = 'Kräv unika e-postadresser för kontaktpersoner';
$lang['AdminCompanyClientOptions.general.boxtitle'] = 'Allmänna klientinställningar';
$lang['AdminCompanyClientoptions.general.page_title'] = 'Inställningar > Företag > Kundalternativ > Allmänt';
$lang['AdminCompanyClientOptions.!tooltip.select_default'] = 'Det markerade alternativvärdet kommer att vara det standardvärde som väljs när detta alternativ läggs till för en kund.';
$lang['AdminCompanyClientOptions.!tooltip.default_checkbox'] = 'Om markerad kommer denna kryssruta att markeras som standard när detta anpassade fält läggs till för en klient.';
$lang['AdminCompanyClientOptions.!tooltip.default_text'] = 'Den text som anges här kommer att vara standardvärdet för detta alternativ när detta anpassade fält läggs till för en kund.';
$lang['AdminCompanyClientOptions.!tooltip.checkbox_value'] = 'Det värde som skickas när kryssrutan är markerad.';
$lang['AdminCompanyClientOptions.!tooltip.encrypted'] = 'Markera den här rutan om du vill lagra värdet krypterat. Detta rekommenderas starkt om du lagrar känslig eller personligt identifierande information.';
$lang['AdminCompanyClientOptions.!tooltip.regex'] = 'Detta alternativ visas om "Obligatoriskt" är inställt på "Anpassat regex". Ange det anpassade reguljära uttrycket som ska valideras för detta fält här.';
$lang['AdminCompanyClientOptions.!tooltip.required'] = 'Välj "Ja" för att säkerställa att ett värde anges för detta fält, för Drop Down-typer måste alternativet visas i listan över alternativ. Välj "Nej" för att acceptera valfritt värde för detta fält. Välj "Anpassat Regex" om du vill använda ett anpassat reguljärt uttryck för att validera detta fält.';
$lang['AdminCompanyClientOptions.!tooltip.read_only_field'] = 'Om du markerar den här rutan kommer det anpassade fältet inte att kunna ändras av kunden. Skrivskyddade fält kommer automatiskt att ställas in på sitt tilldelade standardvärde.';
$lang['AdminCompanyClientOptions.!tooltip.show_client'] = 'Markera för att tillåta klienter att se och uppdatera detta fält.';
$lang['AdminCompanyClientOptions.!tooltip.type'] = 'Det anpassade fältet visas som den valda formulärtypen.';
$lang['AdminCompanyClientOptions.!tooltip.link'] = 'En anpassad länk som kan infogas i fältets namn. Bifoga texten som du vill använda länken till inom hakparenteser (t.ex. [termer]).';
$lang['AdminCompanyClientOptions.!tooltip.is_lang'] = 'Markera endast denna ruta om du har lagt till en språkdefinition för detta anpassade fält i den anpassade språkfilen.';
$lang['AdminCompanyClientOptions.!tooltip.name'] = 'Detta är displaynamnet för detta fält. Det kan vara en språkdefinition.';
$lang['AdminCompanyClientOptions.!tooltip.client_group_id'] = 'Det anpassade fältet kommer endast att gälla för medlemmar i den valda kundgruppen.';
$lang['AdminCompanyClientOptions.!tooltip.clients_increment'] = 'Efterföljande klient-ID:n kommer att öka med detta värde.';
$lang['AdminCompanyClientOptions.!tooltip.clients_start'] = 'Klient-ID Start är startvärdet för klient-ID:n. Nya klienter kommer att ha detta värde, såvida det inte är lägre än värdet för den senast skapade klienten.';
$lang['AdminCompanyClientOptions.!tooltip.clients_format'] = 'Format för klient-ID är formatet för klient-ID. Ett värde på ABC-{num} resulterar i ett klient-ID på ABC-1500 där 1500 är klientens ID-värde.';
$lang['AdminCompanyClientOptions.!tooltip.email_verification'] = 'Markera för att skicka ett e-postmeddelande om verifiering när en ny inloggning skapas eller en kund ändrar sin e-postadress. Ett meddelande kommer att visas på kundens profil tills de är verifierade.';
$lang['AdminCompanyClientOptions.!tooltip.force_email_usernames'] = 'Kunderna måste använda sin e-postadress som användarnamn i stället för att definiera ett eget användarnamn. Befintliga kunder kan fortfarande logga in med sitt nuvarande användarnamn.';
$lang['AdminCompanyClientOptions.!tooltip.unique_contact_emails'] = 'Begränsar e-postadresser för kontakter. Primära kontakter innebär att inga två primära kontakter (t.ex. kunder) kan ha samma e-postadress. Alla kontakter innebär att inga kontakter av någon typ kan ha samma e-postadress som en annan kontakt.';
$lang['AdminCompanyClientOptions.!tooltip.state'] = 'Var försiktig när du kräver att en stat/provins ska väljas. Vissa länder har inga delstater. Kunder i dessa länder skulle inte kunna spara sina kontaktuppgifter. Vi rekommenderar att du inte kräver detta fält.';
$lang['AdminCompanyClientOptions.!tooltip.read_only'] = 'Om markerat kan fältet inte ändras av klienten om det innehåller data.';
$lang['AdminCompanyClientOptions.!error.clients_format'] = 'Klient-ID-formatet måste innehålla {num}.';
$lang['AdminCompanyClientOptions.!notice.group_settings'] = 'OBS: Dessa inställningar gäller endast för kundgrupper som ärver sina inställningar från företaget.';
$lang['AdminCompanyClientOptions.!success.general_updated'] = 'De allmänna inställningarna har uppdaterats.';
$lang['AdminCompanyClientOptions.!success.requiredfields_updated'] = 'De obligatoriska fälten har uppdaterats.';
$lang['AdminCompanyClientOptions.!success.field_deleted'] = 'Det anpassade klientfältet har tagits bort.';
$lang['AdminCompanyClientOptions.!success.field_created'] = 'Det anpassade klientfältet har skapats.';
$lang['AdminCompanyClientOptions.!success.field_updated'] = 'Det anpassade klientfältet har uppdaterats framgångsrikt.';

==> blesta-5.11.4.zip: blesta/language/sv_se/admin_company_clientoptions.php <==
<?php
/**
 * Admin Company Clientoptions
 *
 * @package blesta
 * @subpackage blesta.language.sv_se
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminCompanyClientOptions.requiredfields.text_submit'] = 'Uppdatera inställningar';
$lang['AdminCompanyClientOptions.requiredfields.field_fax'] = 'Fax';
$lang['AdminCompanyClientOptions.requiredfields.field_phone'] = 'Telefon';
$lang['AdminCompanyClientOptions.requiredfields.field_email'] = 'E-post';
$lang['AdminCompanyClientOptions.requiredfields.field_zip'] = 'Postnummer';
$lang['AdminCompanyClientOptions.requiredfields.field_state'] = 'Stat/Provins';
$lang['AdminCompanyClientOptions.requiredfields.field_country'] = 'Land';
$lang['AdminCompanyClientOptions.requiredfields.field_city'] = 'Stad';
$lang['AdminCompanyClientOptions.requiredfields.field_address2'] = 'Adress 2';
$lang['AdminCompanyClientOptions.requiredfields.field_address1'] = 'Adress 1';
$lang['AdminCompanyClientOptions.requiredfields.field_title'] = 'Titel';
$lang['AdminCompanyClientOptions.requiredfields.field_company'] = 'Företag/Org.';
$lang['AdminCompanyClientOptions.requiredfields.field_last_name'] = 'Efternamn';
$lang['AdminCompanyClientOptions.requiredfields.field_first_name'] = 'Förnamn';
$lang['AdminCompanyClientOptions.requiredfields.heading_read_only'] = 'Endast läsning';
$lang['AdminCompanyClientOptions.requiredfields.heading_show'] = 'Visa';
$lang['AdminCompanyClientOptions.requiredfields.heading_required'] = 'Obligatoriskt';
$lang['AdminCompanyClientOptions.requiredfields.heading_field'] = 'Fält';
$lang['AdminCompanyClientOptions.requiredfields.description'] = 'Markera de fält som ska vara obligatoriska när du skapar eller uppdaterar en klient eller kontakt.';
$lang['AdminCompanyClientOptions.requiredfields.boxtitle'] = 'Obligatoriska fält för kunden';
$lang['AdminCompanyClientoptions.requiredfields.page_title'] = 'Inställningar > Företag > Kundalternativ > Kundanpassade fält > Obligatoriska kundfält';
$lang['AdminCompanyClientOptions.getRequired.regex'] = 'Anpassad Regex';
$lang['AdminCompanyClientOptions.getRequired.yes'] = 'Ja';
$lang['AdminCompanyClientOptions.getRequired.no'] = 'Nej';
$lang['AdminCompanyClientOptions.editcustomfield.text_remove'] = 'Ta bort';
$lang['AdminCompanyClientOptions.editcustomfield.heading_select_default'] = 'Standard';
$lang['AdminCompanyClientOptions.editcustomfield.heading_select_option'] = 'Alternativets namn';
$lang['AdminCompanyClientOptions.editcustomfield.heading_select_value'] = 'Värde';
$lang['AdminCompanyClientOptions.editcustomfield.categorylink_select'] = 'Lägg till ytterligare alternativ';
$lang['AdminCompanyClientOptions.editcustomfield.field.default_text'] = 'Standardvärde för text';
$lang['AdminCompanyClientOptions.editcustomfield.field.default_checkbox'] = 'Standardvärde Kontrollerat';
$lang['AdminCompanyClientOptions.editcustomfield.field.checkbox_value'] = 'Värde';
$lang['AdminCompanyClientOptions.editcustomfield.field.editsubmit'] = 'Redigera anpassat fält';
$lang['AdminCompanyClientOptions.editcustomfield.field.encrypted'] = 'Kryptera värden';
$lang['AdminCompanyClientOptions.editcustomfield.field.regex'] = 'Anpassad Regex';
$lang['AdminCompanyClientOptions.editcustomfield.field.required'] = 'Obligatoriskt';
$lang['AdminCompanyClientOptions.editcustomfield.field.read_only'] = 'Endast läsning för klienter';
$lang['AdminCompanyClientOptions.editcustomfield.field.show_client'] = 'Synlig för kunder';
$lang['AdminCompanyClientOptions.editcustomfield.field.type'] = 'Typ';
$lang['AdminCompanyClientOptions.editcustomfield.field.link'] = 'Länk';
$lang['AdminCompanyClientOptions.editcustomfield.field.is_lang'] = 'Namn är en språkdefinition';
$lang['AdminCompanyClientOptions.editcustomfield.field.name'] = 'Namn';
$lang['AdminCompanyClientOptions.editcustomfield.boxtitle_edit'] = 'Redigera anpassat fält';
$lang['AdminCompanyClientoptions.editcustomfield.page_title'] = 'Inställningar > Företag > Klientalternativ > Klientanpassade fält > Redigera anpassat fält';
$lang['AdminCompanyClientOptions.addcustomfield.text_remove'] = 'Ta bort';
$lang['AdminCompanyClientOptions.addcustomfield.heading_select_default'] = 'Standard';
$lang['AdminCompanyClientOptions.addcustomfield.heading_select_option'] = 'Alternativets namn';
$lang['AdminCompanyClientOptions.addcustomfield.heading_select_value'] = 'Värde';
$lang['AdminCompanyClientOptions.addcustomfield.categorylink_select'] = 'Lägg till ytterligare alternativ';
$lang['AdminCompanyClientOptions.addcustomfield.configuration_warning'] = 'Att kräva detta fält men inte göra det synligt för kunderna kommer att leda till att kunderna inte kan registrera eller uppdatera sin kontoinformation.';
$lang['AdminCompanyClientOptions.addcustomfield.field.default_text'] = 'Standardvärde för text';
$lang['AdminCompanyClientOptions.addcustomfield.field.default_checkbox'] = 'Standardvärde Kontrollerat';
$lang['AdminCompanyClientOptions.addcustomfield.field.checkbox_value'] = 'Värde';
$lang['AdminCompanyClientOptions.addcustomfield.field.addsubmit'] = 'Lägg till anpassat fält';
$lang['AdminCompanyClientOptions.addcustomfield.field.encrypted'] = 'Kryptera värden';
$lang['AdminCompanyClientOptions.addcustomfield.field.regex'] = 'Anpassad Regex';
$lang['AdminCompanyClientOptions.addcustomfield.field.required'] = 'Obligatoriskt';
$lang['AdminCompanyClientOptions.addcustomfield.field.read_only'] = 'Endast läsning för klienter';
$lang['AdminCompanyClientOptions.addcustomfield.field.show_client'] = 'Synlig för kunder';
$lang['AdminCompanyClientOptions.addcustomfield.field.type'] = 'Typ';
$lang['AdminCompanyClientOptions.addcustomfield.field.link'] = 'Länk';
$lang['AdminCompanyClientOptions.addcustomfield.field.is_lang'] = 'Namn är en språkdefinition';
$lang['AdminCompanyClientOptions.addcustomfield.field.name'] = 'Namn';
$lang['AdminCompanyClientOptions.addcustomfield.field.client_group_id'] = 'Kundgrupp';
$lang['AdminCompanyClientOptions.addcustomfield.boxtitle_add'] = 'Lägg till anpassat fält';
$lang['AdminCompanyClientoptions.addcustomfield.page_title'] = 'Inställningar > Företag > Klientalternativ > Klientanpassade fält > Lägg till anpassat fält';
$lang['AdminCompanyClientOptions.customfields.no_results'] = 'Det finns inga anpassade fält.';
$lang['AdminCompanyClientOptions.customfields.confirm_delete'] = 'Om du tar bort detta anpassade fält raderas alla data som lagrats för det för varje klient inom denna grupp. Är du säker på att du vill ta bort det här anpassade fältet?';
$lang['AdminCompanyClientOptions.customfields.option_delete'] = 'Radera';
$lang['AdminCompanyClientOptions.customfields.option_edit'] = 'Redigera';
$lang['AdminCompanyClientOptions.customfields.text_options'] = 'Alternativ';
$lang['AdminCompanyClientOptions.customfields.text_read_only'] = 'Endast läsning för klienter';
$lang['AdminCompanyClientOptions.customfields.text_visible'] = 'Synlig för kunder';
$lang['AdminCompanyClientOptions.customfields.text_required'] = 'Obligatoriskt';
$lang['AdminCompanyClientOptions.customfields.text_type'] = 'Typ';
$lang['AdminCompanyClientOptions.customfields.text_name'] = 'Namn';
$lang['AdminCompanyClientOptions.customfields.categorylink_addfield'] = 'Skapa fält';
$lang['AdminCompanyClientOptions.customfields.boxtitle_browse'] = 'Bläddra bland anpassade fält för klienter';
$lang['AdminCompanyClientoptions.customfields.page_title'] = 'Inställningar > Företag > Kundalternativ > Kundanpassade fält > Bläddra';
$lang['AdminCompanyClientOptions.general.text_submit'] = 'Skicka in';
$lang['AdminCompanyClientOptions.general.prevent_unverified_payments'] = 'Förhindra betalningar från icke-verifierade kunder';
$lang['AdminCompanyClientOptions.general.field_clients_increment'] = 'Klient-ID Inkrementvärde';
$lang['AdminCompanyClientOptions.general.field_clients_start'] = 'Kund-ID Startvärde';
$lang['AdminCompanyClientOptions.general.field_clients_format'] = 'Format för klient-ID';
$lang['AdminCompanyClientOptions.general.field_email_verification'] = 'Aktivera e-postverifiering';
$lang['AdminCompanyClientOptions.general.field_force_email_usernames'] = 'Tvinga fram användarnamn för e-post';
$lang['AdminCompanyClientOptions.general.field_unique_contact_emails_all'] = 'Alla kontakter';
$lang['AdminCompanyClientOptions.general.field_unique_contact_emails_primary'] = 'Primära kontakter';
$lang['AdminCompanyClientOptions.general.field_unique_contact_emails_none'] = '-- Inga';
$lang['AdminCompanyClientOptions.general.field_unique_contact_emails'] = 'Kräv unika e-postadresser för kontaktpersoner';
$lang['AdminCompanyClientOptions.general.boxtitle'] = 'Allmänna klientinställningar';
$lang['AdminCompanyClientoptions.general.page_title'] = 'Inställningar > Företag > Kundalternativ > Allmänt';
$lang['AdminCompanyClientOptions.!tooltip.select_default'] = 'Det markerade alternativvärdet kommer att vara det standardvärde som väljs när detta alternativ läggs till för en kund.';
$lang['AdminCompanyClientOptions.!tooltip.default_checkbox'] = 'Om markerad kommer denna kryssruta att markeras som standard när detta anpassade fält läggs till för en klient.';
$lang['AdminCompanyClientOptions.!tooltip.default_text'] = 'Den text som anges här kommer att vara standardvärdet för detta alternativ när detta anpassade fält läggs till för en kund.';
$lang['AdminCompanyClientOptions.!tooltip.checkbox_value'] = 'Det värde som skickas när kryssrutan är markerad.';
$lang['AdminCompanyClientOptions.!tooltip.encrypted'] = 'Markera den här rutan om du vill lagra värdet krypterat. Detta rekommenderas starkt om du lagrar känslig eller personligt identifierande information.';
$lang['AdminCompanyClientOptions.!tooltip.regex'] = 'Detta alternativ visas om "Obligatoriskt" är inställt på "Anpassat regex". Ange det anpassade reguljära uttrycket som ska valideras för detta fält här.';
$lang['AdminCompanyClientOptions.!tooltip.required'] = 'Välj "Ja" för att säkerställa att ett värde anges för detta fält, för Drop Down-typer måste alternativet visas i listan över alternativ. Välj "Nej" för att acceptera valfritt värde för detta fält. Välj "Anpassat Regex" om du vill använda ett anpassat reguljärt uttryck för att validera detta fält.';
$lang['AdminCompanyClientOptions.!tooltip.read_only_field'] = 'Om du markerar den här rutan kommer det anpassade fältet inte att kunna ändras av kunden. Skrivskyddade fält kommer automatiskt att ställas in på sitt tilldelade standardvärde.';
$lang['AdminCompanyClientOptions.!tooltip.show_client'] = 'Markera för att tillåta klienter att se och uppdatera detta fält.';
$lang['AdminCompanyClientOptions.!tooltip.type'] = 'Det anpassade fältet visas som den valda formulärtypen.';
$lang['AdminCompanyClientOptions.!tooltip.link'] = 'En anpassad länk som kan infogas i fältets namn. Bifoga texten som du vill använda länken till inom hakparenteser (t.ex. [termer]).';
$lang['AdminCompanyClientOptions.!tooltip.is_lang'] = 'Markera endast denna ruta om du har lagt till en språkdefinition för detta anpassade fält i den anpassade språkfilen.';
$lang['AdminCompanyClientOptions.!tooltip.name'] = 'Detta är displaynamnet för detta fält. Det kan vara en språkdefinition.';
$lang['AdminCompanyClientOptions.!tooltip.client_group_id'] = 'Det anpassade fältet kommer endast att gälla för medlemmar i den valda kundgruppen.';
$lang['AdminCompanyClientOptions.!tooltip.clients_increment'] = 'Efterföljande klient-ID:n kommer att öka med detta värde.';
$lang['AdminCompanyClientOptions.!tooltip.clients_start'] = 'Klient-ID Start är startvärdet för klient-ID:n. Nya klienter kommer att ha detta värde, såvida det inte är lägre än värdet för den senast skapade klienten.';
$lang['AdminCompanyClientOptions.!tooltip.clients_format'] = 'Format för klient-ID är formatet för klient-ID. Ett värde på ABC-{num} resulterar i ett klient-ID på ABC-1500 där 1500 är klientens ID-värde.';
$lang['AdminCompanyClientOptions.!tooltip.email_verification'] = 'Markera för att skicka ett e-postmeddelande om verifiering när en ny inloggning skapas eller en kund ändrar sin e-postadress. Ett meddelande kommer att visas på kundens profil tills de är verifierade.';
$lang['AdminCompanyClientOptions.!tooltip.force_email_usernames'] = 'Kunderna måste använda sin e-postadress som användarnamn i stället för att definiera ett eget användarnamn. Befintliga kunder kan fortfarande logga in med sitt nuvarande användarnamn.';
$lang['AdminCompanyClientOptions.!tooltip.unique_contact_emails'] = 'Begränsar e-postadresser för kontakter. Primära kontakter innebär att inga två primära kontakter (t.ex. kunder) kan ha samma e-postadress. Alla kontakter innebär att inga kontakter av någon typ kan ha samma e-postadress som en annan kontakt.';
$lang['AdminCompanyClientOptions.!tooltip.state'] = 'Var försiktig när du kräver att en stat/provins ska väljas. Vissa länder har inga delstater. Kunder i dessa länder skulle inte kunna spara sina kontaktuppgifter. Vi rekommenderar att du inte kräver detta fält.';
$lang['AdminCompanyClientOptions.!tooltip.read_only'] = 'Om markerat kan fältet inte ändras av klienten om det innehåller data.';
$lang['AdminCompanyClientOptions.!error.clients_format'] = 'Klient-ID-formatet måste innehålla {num}.';
$lang['AdminCompanyClientOptions.!notice.group_settings'] = 'OBS: Dessa inställningar gäller endast för kundgrupper som ärver sina inställningar från företaget.';
$lang['AdminCompanyClientOptions.!success.general_updated'] = 'De allmänna inställningarna har uppdaterats.';
$lang['AdminCompanyClientOptions.!success.requiredfields_updated'] = 'De obligatoriska fälten har uppdaterats.';
$lang['AdminCompanyClientOptions.!success.field_deleted'] = 'Det anpassade klientfältet har tagits bort.';
$lang['AdminCompanyClientOptions.!success.field_created'] = 'Det anpassade klientfältet har skapats.';
$lang['AdminCompanyClientOptions.!success.field_updated'] = 'Det anpassade klientfältet har uppdaterats framgångsrikt.';
$lang['AdminCompanyClientOptions.gatewayrestrictions.no_gateways_text'] = 'Det finns inga installerade gateways.';
$lang['AdminCompanyClientOptions.gatewayrestrictions.text_gateway_type_hybrid'] = 'Hybrid';
$lang['AdminCompanyClientOptions.gatewayrestrictions.text_gateway_type_merchant'] = 'Köpman';
$lang['AdminCompanyClientOptions.gatewayrestrictions.text_gateway_type_nonmerchant'] = 'Icke-återförsäljare';
$lang['AdminCompanyClientOptions.gatewayrestrictions.heading_type'] = 'Typ';
$lang['AdminCompanyClientOptions.gatewayrestrictions.heading_gateway'] = 'Gateway';
$lang['AdminCompanyClientOptions.gatewayrestrictions.heading_enable'] = 'Aktivera';
$lang['AdminCompanyClientOptions.gatewayrestrictions.field_enable_gateway_restrictions'] = 'Aktivera Gateway-begränsningar';
$lang['AdminCompanyClientOptions.!tooltip.enable_gateway_restrictions'] = 'Begränsa vilka gateways som klienter kan använda. Som standard är Gateway-begränsningar inaktiverade och alla gateways är tillgängliga.';
